@@ -98,7 +98,7 @@ paste("check bpfilter on bpfilterd_spatPomp: ",
 set.seed(5)
 b_bpfilter_filter_traj <- bpfilter(b_bpfilter,filter_traj=TRUE)
 paste("bpfilter filter trajectory final particle: ")
-round(b_bpfilter_filter_traj@filter.traj[,1,N+1],3)
+round(b_bpfilter_filter_traj@filter.traj[,1,],3)
 
 
 set.seed(5)
@@ -115,7 +115,7 @@ b_enkf <- enkf(b_model, Np = Np)
 paste("bm enkf loglik: ",round(logLik(b_enkf),10))
 
 ##
-## girf tested on bm, both moment and bootstrap methods
+## girf on bm: moment and bootstrap methods, followed by error tests
 ##
 
 set.seed(0)
@@ -124,10 +124,11 @@ b_girf_mom <- girf(b_model,Np = floor(Np/2),lookahead = 1,
   kind = 'moment',Ninter=2)
 paste("bm girf loglik, moment guide: ",round(logLik(b_girf_mom),10))
 
+## for boostrap girf, we do not set Ninter, to test the default which is Ninter=U
 set.seed(0)
 b_girf_boot <- girf(b_model,Np = floor(Np/2),lookahead = 1,
   Nguide = floor(Np/2),
-  kind = 'bootstrap',Ninter=2)
+  kind = 'bootstrap')
 paste("bm girf loglik, bootstrap guide: ",round(logLik(b_girf_boot),10))
 
 set.seed(0)
@@ -135,6 +136,12 @@ b_girf_boot_repeat <- girf(b_girf_boot)
 paste("check girf on girfd_spatPomp: ",
   logLik(b_girf_boot)==logLik(b_girf_boot_repeat))
 
+print("The following delivers an error message, to test it")
+try(girf())
+try(girf(object="nonsense"))
+try(girf(b_girf_boot,Np=c(Inf)))
+try(girf(b_girf_boot,Np=seq(from=10,length=N+1,by=2)))
+
 ## ------------------------------------------------------------
 ## Now, we test the inference methods
 ## ____________________________________________________________
@@ -335,6 +342,7 @@ b_rep1 <- spatPomp(b_model,params=coef(b_model))
 for(slt in slotNames(b_model)) if(!identical(slot(b_model,slt),slot(b_rep1,slt))) print(slt)
 
 # test an error message
+print("The following delivers an error message, to test it")
 try(spatPomp(data=as.data.frame(b_model),units=NULL),outFile=stdout())
 
 # test parameter replacement
